@@ -920,7 +920,8 @@ no_moves:
       }
 
       if (board.bbc[board.side_to_move].is_empty())
-         best_score = no_piece_score + depth;
+         best_score = (no_piece_score < 0) ? no_piece_score + depth
+                                           : no_piece_score - depth;
 
       if (best_score == depth) hash_flag = HASH_TYPE_UPPER;
 
@@ -968,7 +969,7 @@ void print_principle_variation(int d = 0)
          iter(" %d.", (int)(root_move_number+moves_played)/2+1);
       movelist_t movelist;
       generate_legal_moves(&movelist);
-      iter(" %-6s", move_to_short_string(principle_variation[c][d], &movelist));
+      iter(" %-6s", move_to_short_string(principle_variation[c][d], &movelist, NULL, castle_san_ok));
       playmove(principle_variation[c][d]);
    }
    for (c=0; c<length_of_variation[d]; c++)
@@ -987,7 +988,7 @@ void print_principle_variation_xb(movelist_t *movelist = NULL)
    for (c=0; c<length_of_variation[0]; c++) {
       if (((root_move_number+c) & 1) == 0)
          xb(" %d.", (int)(root_move_number+moves_played)/2+1);
-      xb(" %s", move_to_short_string(principle_variation[c][0], movelist));
+      xb(" %s", move_to_short_string(principle_variation[c][0], movelist, NULL, castle_san_ok));
       playmove(principle_variation[c][0]);
    }
    for (c=0; c<length_of_variation[0]; c++)
@@ -1139,7 +1140,8 @@ play_state_t think(int max_depth)
    /* Prepare the transpostion table for a new search iteration:
     * Resets the write count and increases the generation counter.
     */
-   prepare_hashtable_search(transposition_table);
+   if (!analysing)
+      prepare_hashtable_search(transposition_table);
 
    int hash_depth, hash_score;
    uint32_t hash_flag;
@@ -1194,13 +1196,13 @@ play_state_t think(int max_depth)
                iter("% 3d.  %6.2f   %9d  %+2.2f  ", depth, (get_timer()-start_time)/1000000.0, (int)clock.nodes_searched, score/100.0);
                iter(" %d.", (int)(start_move_count + moves_played)/2+1);
                if (board.side_to_move) iter(" ...");
-               iter(" %s?", move_to_short_string(move, &movelist));
+               iter(" %s?", move_to_short_string(move, &movelist, NULL, castle_san_ok));
                iter("\n");
 
                xb("% 3d % 5d %6d %9d ", depth, score, (int)(get_timer()-start_time)/10000, (int)clock.nodes_searched);
                xb(" %d.", (int)(start_move_count + moves_played)/2+1);
                if (board.side_to_move) xb(" ...");
-               xb(" %s?", move_to_short_string(move, &movelist));
+               xb(" %s?", move_to_short_string(move, &movelist, NULL, castle_san_ok));
                xb("\n");
             }
             clock.extra_time = (9*clock.time_left)/10;
@@ -1214,13 +1216,13 @@ play_state_t think(int max_depth)
                iter("% 3d.  %6.2f   %9d  %+2.2f  ", depth, (get_timer()-start_time)/1000000.0, (int)clock.nodes_searched, score/100.0);
                iter(" %d.", (int)(start_move_count + moves_played)/2+1);
                if (board.side_to_move) iter(" ...");
-               iter(" %s!", move_to_short_string(move, &movelist));
+               iter(" %s!", move_to_short_string(move, &movelist, NULL, castle_san_ok));
                iter("\n");
 
                xb("% 3d % 5d %6d %9d ", depth, score, (int)(get_timer()-start_time)/10000, (int)clock.nodes_searched);
                xb(" %d.", (int)(start_move_count + moves_played)/2+1);
                if (board.side_to_move) xb(" ...");
-               xb(" %s!", move_to_short_string(move, &movelist));
+               xb(" %s!", move_to_short_string(move, &movelist, NULL, castle_san_ok));
                xb("\n");
             }
             clock.extra_time = (5*clock.time_left)/10;
@@ -1234,8 +1236,8 @@ play_state_t think(int max_depth)
       print_principle_variation_xb(&movelist);
       xb("\n");
 
-      uci("info depth %d score cp %d nodes %llu time %llu hashfull %d pv",
-            depth, score, (unsigned long long)clock.nodes_searched, (unsigned long long)peek_timer(&clock), (int)std::min(1000, (int)(transposition_table->write_count*1000/transposition_table->number_of_elements)));
+      uci("info depth %d score cp %d nodes %d time %d hashfull %d pv",
+            depth, score, (int)clock.nodes_searched, (int)peek_timer(&clock), (int)std::min(1000, (int)(transposition_table->write_count*1000/transposition_table->number_of_elements)));
       print_principle_variation_uci();
       uci("\n");
 
